<?php
$TRANSLATIONS = array(
"Email sent" => "Email geschéckt",
"Unable to load list from App Store" => "Konnt Lescht net vum App Store lueden",
"Authentication error" => "Authentifikatioun's Fehler",
"Group already exists" => "Group existeiert schon.",
"Unable to add group" => "Onmeiglech Grupp beizefügen.",
"Email saved" => "E-mail gespäichert",
"Invalid email" => "Ongülteg e-mail",
"Unable to delete group" => "Onmeiglech d'Grup ze läschen.",
"Unable to delete user" => "Onmeiglech User zu läschen.",
"Language changed" => "Sprooch huet geännert",
"Invalid request" => "Ongülteg Requête",
"Admins can't remove themself from the admin group" => "Admins kennen sech selwer net aus enger Admin Group läschen.",
"Unable to add user to group %s" => "Onmeiglech User an Grupp ze sätzen %s",
"Disable" => "Ofschalten",
"Enable" => "Aschalten",
"Error" => "Fehler",
"Update" => "Update",
"undo" => "réckgängeg man",
"Groups" => "Gruppen",
"Group Admin" => "Gruppen Admin",
"Delete" => "Läschen",
"never" => "ni",
"__language_name__" => "__language_name__",
"Login" => "Login",
"Security Warning" => "Sécherheets Warnung",
"Cron" => "Cron",
"Allow apps to use the Share API" => "Erlab Apps d'Share API ze benotzen",
"Allow resharing" => "Resharing erlaben",
"Server address" => "Server Adress",
"Log" => "Log",
"More" => "Méi",
"Less" => "Manner",
"Add your App" => "Setz deng App bei",
"Select an App" => "Wiel eng Applikatioun aus",
"See application page at apps.owncloud.com" => "Kuck dir d'Applicatioun's Säit op apps.owncloud.com un",
"All" => "All",
"Password" => "Passwuert",
"Unable to change your password" => "Konnt däin Passwuert net änneren",
"Current password" => "Momentan 't Passwuert",
"New password" => "Neit Passwuert",
"Change password" => "Passwuert änneren",
"Email" => "Email",
"Your email address" => "Deng Email Adress",
"Cancel" => "Ofbriechen",
"Language" => "Sprooch",
"Help translate" => "Hëllef iwwersetzen",
"Login Name" => "Login",
"Create" => "Erstellen",
"Group" => "Grupp",
"Default Quota" => "Standard Quota",
"Other" => "Aner",
"Username" => "Benotzernumm",
"Quota" => "Quota"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
